@@ -2,6 +2,7 @@ from .cartpole import CartPoleJiminyEnv
 from .acrobot import AcrobotJiminyEnv, AcrobotJiminyGoalEnv
 from .anymal import ANYmalJiminyEnv, ANYmalPDControlJiminyEnv
 from .atlas import AtlasJiminyEnv, AtlasPDControlJiminyEnv  # noqa
+from .spotmicro import SpotmicroJiminyEnv  # noqa
 
 __all__ = [
     'CartPoleJiminyEnv',
@@ -10,5 +11,6 @@ __all__ = [
     'ANYmalJiminyEnv',
     'ANYmalPDControlJiminyEnv',
     'AtlasJiminyEnv',
-    'AtlasPDControlJiminyEnv'
+    'AtlasPDControlJiminyEnv',
+    'SpotmicroJiminyEnv'
 ]
